==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/20/202886b046816bf321b5b2221a418c04.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Translations/en_US/validators.ini */
class __TwigTemplate_4668f12a99c7ff6515cde6c0c2dc668a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.report.schedule.notValid=\"Schedule settings is not valid. Please fill all required fields\"
mautic.report.schedule.to_address_required=\"To address is required for scheduling report\"
mautic.report.schedule.invalidScheduler=\"Scheduler is not valid\"
mautic.report.schedule.notSupportedType=\"This scheduler is not supported\"
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Translations/en_US/validators.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Translations/en_US/validators.ini", "/var/www/html/mauticGIT-Test/app/bundles/ReportBundle/Translations/en_US/validators.ini");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/20/202886b046816bf321b5b2221a418c04.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Translations/en_US/validators.ini */
class __TwigTemplate_4668f12a99c7ff6515cde6c0c2dc668a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.report.schedule.notValid=\"Schedule settings is not valid. Please fill all required fields\"
mautic.report.schedule.to_address_required=\"To address is required for scheduling report\"
mautic.report.schedule.invalidScheduler=\"Scheduler is not valid\"
mautic.report.schedule.notSupportedType=\"This scheduler is not supported\"
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Translations/en_US/validators.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Translations/en_US/validators.ini", "/var/www/html/production-demo/app/bundles/ReportBundle/Translations/en_US/validators.ini");
    }
}
